/*
 * iec-plus4exp.c - IEC drive PLUS4 expansion specific routines.
 *
 * Written by
 *  Andreas Boose <viceteam@t-online.de>
 *
 * This file is part of VICE, the Versatile Commodore Emulator.
 * See README for copyright notice.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 *  02111-1307  USA.
 *
 */

#include "vice.h"

#include "iec-plus4exp.h"
#include "drivetypes.h"
#include "lib.h"
#include "plus4exp-cmdline-options.h"
#include "plus4exp-resources.h"


int iec_plus4exp_resources_init(void)
{
    return plus4exp_resources_init();
}

void iec_plus4exp_resources_shutdown(void)
{
    plus4exp_resources_shutdown();
}

int iec_plus4exp_cmdline_options_init(void)
{
    return plus4exp_cmdline_options_init();
}

void iec_plus4exp_init(struct diskunit_context_s *drv)
{
}

void iec_plus4exp_reset(struct diskunit_context_s *drv)
{
}

void iec_plus4exp_mem_init(struct diskunit_context_s *drv, unsigned int type)
{
}
